@@ -226,7 +226,7 @@ sub get_config_objects {
             push @remove, $svc if $svc;
             # only save disabled information if it was disabled manually, not when disabled by config
             # and only if it wasn't orphaned
-            if(!$chk->{'disabled'} && $chk->{'exists'} ne 'obsolete') {
+            if(!$chk->{'disabled'} && $chk->{'exists'} ne 'obsolete' && !$chk->{'exclude_reason'}) {
                 push @{$settings->{'disabled'}}, $id;
             }
             next;
@@ -339,7 +339,8 @@ sub get_config_objects {
         @list = @cloned;
     }
 
-    return(\@list, \@remove);
+    my $sorted = [(sort { $a->{'type'} cmp $b->{'type'} || ($a->{'conf'}->{'service_description'}//'') cmp ($b->{'conf'}->{'service_description'}//'') } @list)];
+    return($sorted, \@remove);
 }
 
 ##########################################################
